# Generated by Django 5.1 on 2024-10-20 14:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0019_alter_customer_customer_group'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='document_check_digit',
            field=models.CharField(blank=True, help_text='Customer document check digit', max_length=10, null=True, verbose_name='Customer document check digit'),
        ),
    ]
